# -*- coding: utf-8 -*-
# mypy: disable-error-code="import"
# pylint: disable=import-error
"""pyproject.toml helpers."""

import typing as t
from pathlib import Path

from aea.configurations.data_types import Dependency as PyPiDependency


PYPROJECT_TOML = "pyproject.toml"
DEFAULT_PYPROJECT_TOML = """# This file is auto-generated by compose CLI tool

[tool.poetry]
name = <NAME>
version = "0.1.0"
description = <DESCRIPTION>
authors = ["author <author@mail.com>"]
license = <LICENSE>
readme = "README.md"

[tool.poetry.dependencies]
python = ">=3.8,<4"
{dependencies}
"""


def init_pyproject_toml(wd: Path, core_dependencies: t.List[PyPiDependency]) -> None:
    """Initialize Pipfile"""
    dependencies = ""
    for dep in core_dependencies:
        dependencies += dep.to_pipfile_string() + "\n"
    (wd / PYPROJECT_TOML).write_text(
        DEFAULT_PYPROJECT_TOML.format(dependencies=dependencies)
    )
